﻿Anritsu                                                     MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub MG369XC Flatness Cal /N5531S
DATE:                  2014-02-22 15:22:19
AUTHOR:                Fluke
REVISION:              $Revision: 8098 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       1
NUMBER OF LINES:       101
=============================================================================
#
#  Text Source:
#    $RCSfile: sub_mg369xc_flatnesscal_n5531s.mc $
#    $Date: 2014-06-10 06:40:01 -0700 (Tue, 10 Jun 2014) $
#
#  Procedure Author:
#        AWS
#
#  Model(s) Covered:
#        MG369XC
#
#  Compatibility:
#        MET/CAL 8.0 or later
#
#  Subprocedures:
#        Sub MG369XC Init Cal Correction File
#        Sub MG369XC Level Adj Connection /N5531S
#        Sub MG369XC Init Measure Flatness Power /N5531S
#        Sub MG369XC Measure Flatness /N5531S
#        Sub MG369XC Increment Flatness Cal Freq
#        Sub MG369XC Store Flatness Corrections
#        Sub Get Offset Value
#
#  Required Files:
#        None
#
#  Additional Equipment Required:
#        None
#
#  The copyright for this procedure is owned by Anritsu Company.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

  1.001  HEAD         {Flatness Calibration}
  1.002  HEAD         -2

# Prepare the temporary correction file
  1.003  CALL         Sub MG369XC Init Cal Correction File

# Set the sensor switch point frequency to 2 GHz so that units without
# downconverters will calibrate without having to switch sensors.
  1.004  MATH         @N5532_PS_Switch_Freq = 2

# Prepare the signal generator for flatness calibration
  1.005  IEEE         RST[D2000]RF0
  1.006  IEEE         CSB SQ1 MB2D SB1 WH1[D2000]
  1.007  IEEE         WHF128[D50]

  1.008  TARGET       -p

# Calibration starts no lower than 10 MHz
  1.009  MATH         @FreqGHz =  MAX2(@FreqLowGHz, 0.010)

# Prepare the N5531S for flatness cal measurements
  1.010  MATH         @ConnPadValue = 0
  1.011  MATH         @LvldBm = 15
  1.012  CALL         Sub MG369XC Level Adj Connection /N5531S
  1.013  CALL         Sub MG369XC Init Measure Flatness Power /N5531S

  1.014  WHILE        @FreqGHz <= @FreqHighGHz

  1.015  TARGET       -p

# An arbitrary @LvldBm is set to satisfy the N5531S FSC in the connection
# proc.
  1.016  MATH         @ConnPadValue = 0
  1.017  MATH         @LvldBm = 15
  1.018  CALL         Sub MG369XC Level Adj Connection /N5531S

# Determine the amount the adapters and pads affect the power measurement
# at this frequency.
  1.019  MATH         @Offset_FreqGHz = @FreqGHz
  1.020  CALL         Sub Get Offset Value

# Measure flatness at this frequency over all the power levels.
  1.021  CALL         Sub MG369XC Measure Flatness /N5531S
  1.022  CALL         Sub MG369XC Increment Flatness Cal Freq
  1.023  ENDW

  1.024  TARGET       -p

# Store the corrections into the unit
  1.025  CALL         Sub MG369XC Store Flatness Corrections

# Close the correction file so that it can be initialized and reused later.
  1.026  MATH         CLOSE(@CorrectionFile)

# End the calibration, save the results, and exit Cal mode.
  1.027  IEEE         WHX PGM [SRQ 5000] WH0
  1.028  WAIT         -a -t 15 Please wait for the unit to restart
  1.029  END
